@@ -6,6 +6,7 @@ from .abstract import AuthStorage
 
 class PostgresStorage(AuthStorage):
     driver: str = "pg"
+    name: str = 'authdb'
     pool_based: bool = True
     timeout: int = 3600
 
@@ -17,7 +18,8 @@ class PostgresStorage(AuthStorage):
         **kwargs
     ):
         kwargs = {
-            "min_size": 5,
+            "min_size": 2,
+            "max_size": 100,
             "server_settings": {
                 "application_name": 'NAV-AUTH',
                 "client_min_messages": "notice",
@@ -47,4 +49,3 @@ class PostgresStorage(AuthStorage):
     async def cleanup(self, app: web.Application):
         """Called when application ends.
         """
-        pass
